@@ -1,5 +1,5 @@
 from testcase.state_testing_app.state_modules import TestRedis
-from worker import App
+from worker.app import App
 
 
 class TestingApp(App):
