@@ -1,11 +1,12 @@
-from worker.app.modules.__init__ import Module
+from worker.app.modules.activity_module import ActivityModule
 
 
-class DepthActivityModule(Module):
+class DepthActivityModule(ActivityModule):
     """
     This is an abstract module that needs to be extended by actual modules.
     An example of this module would be running an app every 1 ft.
     """
+
     module_key = "depth_activity_module"
     collection = "depth_activity_collection"
 
