@@ -1,5 +1,5 @@
-from collections import OrderedDict
 import itertools
+from collections import OrderedDict
 from typing import List, Union
 
 from worker.data import operations
@@ -11,11 +11,7 @@ from worker.data.wits import WITS
 
 @serialization
 class ActivityGroup:
-    SERIALIZED_VARIABLES = {
-        'activity': Activity,
-        'start': int,
-        'end': int
-    }
+    SERIALIZED_VARIABLES = {"activity": Activity, "start": int, "end": int}
 
     def __init__(self, activity: Activity, start: int, end: int, **kwargs):
         self.activity = activity
@@ -31,8 +27,13 @@ class ActivityGroup:
         return self.end - self.start + 1
 
     @classmethod
-    def merge(cls, grp1: 'ActivityGroup', grp2: 'ActivityGroup',
-              max_duration_gap: int = None, resultant_activity: Activity = None) -> Union['ActivityGroup', None]:
+    def merge(
+        cls,
+        grp1: "ActivityGroup",
+        grp2: "ActivityGroup",
+        max_duration_gap: int = None,
+        resultant_activity: Activity = None,
+    ) -> Union["ActivityGroup", None]:
         """
         Merging two groups of activities into one.
         :param grp1:
@@ -61,7 +62,7 @@ class ActivityGroup:
         return ActivityGroup(resultant_activity, min_start, max_end)
 
     @staticmethod
-    def has_overlap(group1: 'ActivityGroup', group2: 'ActivityGroup') -> bool:
+    def has_overlap(group1: "ActivityGroup", group2: "ActivityGroup") -> bool:
         """
         Checking if two activity groups has overlap regardless of their precedence
         :param group1:
@@ -92,27 +93,32 @@ part of the bounding activities. For instance, you might be Reaming Down and
 for a second the bit depth is the same as the previous timestamp and the activity
 is Rotary Off Bottom. This will then be grouped into Reaming Down group.
 """
-NEUTRAL_ACTIVITIES = OrderedDict([
-    (Activity.RUN_IN_HOLE, [Activity.STATIC_OFF_BOTTOM]),
-    (Activity.PULL_OUT_OF_HOLE, [Activity.STATIC_OFF_BOTTOM]),
-    (Activity.WASHING_DOWN, [Activity.CIRCULATING]),
-    (Activity.WASHING_UP, [Activity.CIRCULATING]),
-    (Activity.DRY_REAMING_DOWN, [Activity.DRY_ROTARY_OFF_BOTTOM]),
-    (Activity.DRY_REAMING_UP, [Activity.DRY_ROTARY_OFF_BOTTOM]),
-    (Activity.REAMING_DOWN, [Activity.ROTARY_OFF_BOTTOM]),
-    (Activity.REAMING_UP, [Activity.ROTARY_OFF_BOTTOM]),
-
-    (Activity.STATIC_OFF_BOTTOM, [Activity.RUN_IN_HOLE, Activity.PULL_OUT_OF_HOLE]),
-    (Activity.CIRCULATING, [Activity.WASHING_DOWN, Activity.WASHING_UP]),
-    (Activity.DRY_ROTARY_OFF_BOTTOM, [Activity.DRY_REAMING_DOWN, Activity.DRY_REAMING_UP]),
-    (Activity.ROTARY_OFF_BOTTOM, [Activity.REAMING_DOWN, Activity.REAMING_UP]),
-])
+NEUTRAL_ACTIVITIES = OrderedDict(
+    [
+        (Activity.RUN_IN_HOLE, [Activity.STATIC_OFF_BOTTOM]),
+        (Activity.PULL_OUT_OF_HOLE, [Activity.STATIC_OFF_BOTTOM]),
+        (Activity.WASHING_DOWN, [Activity.CIRCULATING]),
+        (Activity.WASHING_UP, [Activity.CIRCULATING]),
+        (Activity.DRY_REAMING_DOWN, [Activity.DRY_ROTARY_OFF_BOTTOM]),
+        (Activity.DRY_REAMING_UP, [Activity.DRY_ROTARY_OFF_BOTTOM]),
+        (Activity.REAMING_DOWN, [Activity.ROTARY_OFF_BOTTOM]),
+        (Activity.REAMING_UP, [Activity.ROTARY_OFF_BOTTOM]),
+        (Activity.STATIC_OFF_BOTTOM, [Activity.RUN_IN_HOLE, Activity.PULL_OUT_OF_HOLE]),
+        (Activity.CIRCULATING, [Activity.WASHING_DOWN, Activity.WASHING_UP]),
+        (Activity.DRY_ROTARY_OFF_BOTTOM, [Activity.DRY_REAMING_DOWN, Activity.DRY_REAMING_UP]),
+        (Activity.ROTARY_OFF_BOTTOM, [Activity.REAMING_DOWN, Activity.REAMING_UP]),
+    ]
+)
 
 
 class ActivityGrouping:
     def __init__(
-        self, min_group_duration: int = 3, apply_neutral_grouping: bool = True, apply_gap_filling: bool = True,
-        merging_dict: dict = None, time_step=None
+        self,
+        min_group_duration: int = 3,
+        apply_neutral_grouping: bool = True,
+        apply_gap_filling: bool = True,
+        merging_dict: dict = None,
+        time_step=None,
     ):
         """
         :param min_group_duration: minimum duration of each group
@@ -154,9 +160,7 @@ class ActivityGrouping:
             valid_timestamps = [timestamps[i] for i in range(len(timestamps)) if activities[i] == activity]
             # Grouping and finding the edges of the activities
             edges = split_zip_edges(
-                valid_timestamps,
-                separation_length=self.time_step,
-                min_segment_length=self.min_group_duration
+                valid_timestamps, separation_length=self.time_step, min_segment_length=self.min_group_duration
             )
             this_groups = [ActivityGroup(activity=activity, start=start, end=end) for (start, end) in edges]
             groups.extend(this_groups)
@@ -171,7 +175,7 @@ class ActivityGrouping:
             # 2. merging adjacent activities with similar merging activities
             index = 1
             while index < len(groups):
-                grp1, grp2 = groups[index - 1: index + 1]
+                grp1, grp2 = groups[index - 1 : index + 1]
                 merged_group = ActivityGroup.merge(grp1, grp2, max_duration_gap=max(self.time_step, 2))
                 if not merged_group:
                     index += 1
