@@ -138,15 +138,14 @@ class MergingProgress:
         Returns:
             None
         """
-        collections = request.get("included") or []
+        progresses = request.get("included") or []
 
-        for collection in collections:
-            attributes = collection.get("attributes") or {}
-            dataset_name = attributes.get("dataset_name")
-
-            if not dataset_name:
+        for progress in progresses:
+            if progress.get("type") != "partial_well_rerun_dataset_progress":
                 continue
 
+            attributes = progress.get("attributes") or {}
+
             dataset_progress = DatasetProgress.set_from_dict(attributes)
             self.dataset_progresses.append(dataset_progress)
 
